/*
*/

#pragma once
#ifndef ALIAS_H
#define ALIAS_H

#define STRING_CAST_CHAR
#include "datatypes.h"

#include <time.h>

#define HTONL(x) ( (((x) & 0x000000ff) << 24) | (((x) & 0x0000ff00) << 8) | (((x) & 0x00ff0000) >> 8) | (((x) & 0xff000000) >> 24) )

Uint32 get_ip(const char *cp);
Uint32 get_name_hash(const char *name);


/* *info & *tinfo Snapshot */
struct info_snapshot
{
	Uint32 name_hash;
	char name[24];
	Uint32 ip;
	Sint32 tzb;
	Sint32 id;
	Sint32 timediff;
	time_t seen;
};


/* Efficient memory storage */
#define MEMORY_LENGTH 10

struct alias_data
{
	Uint32 ip;
	Sint32 tzb;
	Sint32 id;
};

struct alias_name
{
	Uint32 name_hash;
	char name[24];
	time_t seen;
	Sint32 timediff;

	alias_data *data[MEMORY_LENGTH];
};

extern _linkedlist <alias_name> AliasList;
extern bool ListChanged;


/* Disk access */

struct disk_name
{
	char name[24];
	time_t seen;
	Sint32 timediff;
	Sint32 data_count;
};

bool save_aliases(char *fn);
bool load_aliases(char *fn);


/* Accessors */

void UpdateHash(alias_name &snapshot);
void UpdateSeen(alias_name &snapshot);

alias_name *AddAlias(info_snapshot &snapshot);
void AddData(alias_name *name, info_snapshot &snapshot);
alias_name *FindSnapshot(char *name);
bool old_info(alias_name *name, info_snapshot &snapshot);
String GetLastSeen(char *name);

#endif	// ALIAS_H
